import React from 'react';
import { BrowserRouter as Router, Route, Switch } from "react-router-dom";

import Navigation from './Navigation';
import Footer from './Footer';
import Home from './Home';
import About from './About';

// Maps
import Pigeon from './Pigeon';
import MapGL from './MapGL';
import Leaflet from './Leaflet';
import Google from './Google';
import Mapbox from './Mapbox';

import {calcDistance} from './helpers/distance';

export class App extends React.Component{
    constructor(props) {
        super(props)

        this.state = {
            mapConfig: {
                zoom: 15,
                path: [],
                coords: [48.336950, 14.320570],
                width: 600,
                height: 400,
                defaultZoom: 15,
                distance: 0,
            }
        }
    }

    updateMapState = (key, value) => {
        let mapConfigCopy = JSON.parse(JSON.stringify(this.state.mapConfig));
        mapConfigCopy[key] = value;
        this.setState({mapConfig: mapConfigCopy})
    }

    getDistance = () => {
        let dst = calcDistance(this.state.mapConfig.path)
        this.updateMapState("distance", dst)
    }

    render(){
        return (
          <div>
              <Router>
                <Navigation />
                <Switch>
                  <Route path="/" exact component={Home} />
                  <Route path="/about" exact component={About} />
                  <Route exact path="/pigeon-map" render={() =>
                    <Pigeon
                        mapConfig={this.state.mapConfig}
                        updateMapState={this.updateMapState}
                        getDistance={this.getDistance}
                    />}
                  />
                  <Route path="/map-gl" exact component={MapGL} />
                  <Route path="/leaflet" exact component={Leaflet} />
                  <Route path="/google-map" exact component={Google} />
                    <Route path="/mapbox" exact component={Mapbox} />
                </Switch>
                <Footer />
              </Router>
          </div>
        )
    }

}